@@ -1,5 +1,5 @@
 #include "model/terminal_rules/BINARY_OPERATOR.h"
-#include <sstream>
+
 #include <cassert>
 #include <list>
 
@@ -7,13 +7,6 @@ using namespace std;
 
 // ---------------------------------------------------------------------------
 
-BINARY_OPERATOR* BINARY_OPERATOR::Clone() const
-{
-  return new BINARY_OPERATOR(*this);
-}
-
-// ---------------------------------------------------------------------------
-
 const bool BINARY_OPERATOR::Check_For_String()
 {
   if (!Is_Valid())
@@ -21,53 +14,55 @@ const bool BINARY_OPERATOR::Check_For_String()
 
   m_string_count++;
 
-  return (m_string_count <= 4);
-}
-
-// ---------------------------------------------------------------------------
-
-const list<string> BINARY_OPERATOR::Get_String() const
-{
-  assert(m_string_count <= 4);
-
-  list<string> strings;
-
-  stringstream temp_stream;
-  temp_stream << Get_Value();
-
-  strings.push_back(temp_stream.str());
-  return strings;
-}
-
-// ---------------------------------------------------------------------------
-
-string BINARY_OPERATOR::Get_Value() const
-{
-  assert(m_string_count <= 4);
+  if (m_string_count > 4)
+    return false;
 
   switch (m_string_count)
   {
     case 1 :
     {
-      return string("<=>");
+      return_value = "<=>";
       break;
     }
     case 2 :
     {
-      return string("and");
+      return_value = "and";
       break;
     }
     case 3 :
     {
-      return string("or");
+      return_value = "or";
       break;
     }
     case 4 :
     {
-      return string("=>");
+      return_value = "=>";
       break;
     }
+
   }
 
-  return string();
+  strings.clear();
+
+  strings.push_back(return_value);
+
+  return true;
+}
+
+// ---------------------------------------------------------------------------
+
+const list<string>& BINARY_OPERATOR::Get_String() const
+{
+  assert(m_string_count <= 4);
+
+  return strings;
+}
+
+// ---------------------------------------------------------------------------
+
+const string& BINARY_OPERATOR::Get_Value()
+{
+  Set_Accessed(true);
+
+  return return_value;
 }
